@@ -3,7 +3,7 @@ package DateTime::Locale::Catalog;
 use strict;
 use warnings;
 
-our $VERSION = '0.96';
+our $VERSION = '1.15';
 
 1;
 
@@ -13,20 +13,20 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Locale::Catalog - Provides a catalog of all valid locale names
 
 =head1 VERSION
 
-version 0.96
+version 1.15
 
 =head1 DESCRIPTION
 
 This module contains a list of all known locales.
 
-=encoding UTF-8
-
 =head1 LOCALES
 
 Any method taking locale code or name arguments should use one of the values
@@ -93,11 +93,11 @@ The available locales are:
  asa-TZ           Asu Tanzania                              Kipare Tadhania
  ast              Asturian                                  asturianu
  ast-ES           Asturian Spain                            asturianu España
- az               Azerbaijani                               azərbaycan dili
- az-Cyrl          Azerbaijani Cyrillic                      азәрбајҹан дили Кирил
- az-Cyrl-AZ       Azerbaijani Azerbaijan Cyrillic           азәрбајҹан дили Азәрбајҹан Кирил
- az-Latn          Azerbaijani Latin                         azərbaycan dili latın
- az-Latn-AZ       Azerbaijani Azerbaijan Latin              azərbaycan dili Azərbaycan latın
+ az               Azerbaijani                               azərbaycan
+ az-Cyrl          Azerbaijani Cyrillic                      азәрбајҹан Кирил
+ az-Cyrl-AZ       Azerbaijani Azerbaijan Cyrillic           азәрбајҹан Азәрбајҹан Кирил
+ az-Latn          Azerbaijani Latin                         azərbaycan latın
+ az-Latn-AZ       Azerbaijani Azerbaijan Latin              azərbaycan Azərbaycan latın
  bas              Basaa                                     Ɓàsàa
  bas-CM           Basaa Cameroon                            Ɓàsàa Kàmɛ̀rûn
  be               Belarusian                                беларуская
@@ -110,9 +110,9 @@ The available locales are:
  bg-BG            Bulgarian Bulgaria                        български България
  bm               Bambara                                   bamanakan
  bm-ML            Bambara Mali                              bamanakan Mali
- bn               Bengali                                   বাংলা
- bn-BD            Bengali Bangladesh                        বাংলা বাংলাদেশ
- bn-IN            Bengali India                             বাংলা ভারত
+ bn               Bangla                                    বাংলা
+ bn-BD            Bangla Bangladesh                         বাংলা বাংলাদেশ
+ bn-IN            Bangla India                              বাংলা ভারত
  bo               Tibetan                                   བོད་སྐད་
  bo-CN            Tibetan China                             བོད་སྐད་ རྒྱ་ནག
  bo-IN            Tibetan India                             བོད་སྐད་ རྒྱ་གར་
@@ -136,10 +136,10 @@ The available locales are:
  cgg              Chiga                                     Rukiga
  cgg-UG           Chiga Uganda                              Rukiga Uganda
  chr              Cherokee                                  ᏣᎳᎩ
- chr-US           Cherokee United States                    ᏣᎳᎩ ᎠᎹᏰᏟ
+ chr-US           Cherokee United States                    ᏣᎳᎩ ᏌᏊ ᎢᏳᎾᎵᏍᏔᏅ ᏍᎦᏚᎩ
  ckb              Central Kurdish                           کوردیی ناوەندی
- ckb-IQ           Central Kurdish Iraq                      کوردیی ناوەندی IQ
- ckb-IR           Central Kurdish Iran                      کوردیی ناوەندی IR
+ ckb-IQ           Central Kurdish Iraq                      کوردیی ناوەندی عێراق
+ ckb-IR           Central Kurdish Iran                      کوردیی ناوەندی ئێران
  cs               Czech                                     čeština
  cs-CZ            Czech Czech Republic                      čeština Česká republika
  cu               Church Slavic                             cu
@@ -156,6 +156,7 @@ The available locales are:
  de-BE            German Belgium                            Deutsch Belgien
  de-CH            German Switzerland                        Deutsch Schweiz
  de-DE            German Germany                            Deutsch Deutschland
+ de-IT            German Italy                              Deutsch Italien
  de-LI            German Liechtenstein                      Deutsch Liechtenstein
  de-LU            German Luxembourg                         Deutsch Luxemburg
  dje              Zarma                                     Zarmaciine
@@ -288,6 +289,7 @@ The available locales are:
  es-419           Spanish Latin America                     español Latinoamérica
  es-AR            Spanish Argentina                         español Argentina
  es-BO            Spanish Bolivia                           español Bolivia
+ es-BR            Spanish Brazil                            español Brasil
  es-CL            Spanish Chile                             español Chile
  es-CO            Spanish Colombia                          español Colombia
  es-CR            Spanish Costa Rica                        español Costa Rica
@@ -489,7 +491,7 @@ The available locales are:
  lkt-US           Lakota United States                      Lakȟólʼiyapi Mílahaŋska Tȟamákȟočhe
  ln               Lingala                                   lingála
  ln-AO            Lingala Angola                            lingála Angóla
- ln-CD            Lingala Congo - Kinshasa                  lingála Repibiki demokratiki ya Kongó
+ ln-CD            Lingala Congo - Kinshasa                  lingála Republíki ya Kongó Demokratíki
  ln-CF            Lingala Central African Republic          lingála Repibiki ya Afríka ya Káti
  ln-CG            Lingala Congo - Brazzaville               lingála Kongo
  lo               Lao                                       ລາວ
@@ -536,8 +538,8 @@ The available locales are:
  mt-MT            Maltese Malta                             Malti Malta
  mua              Mundang                                   MUNDAŊ
  mua-CM           Mundang Cameroon                          MUNDAŊ kameruŋ
- my               Burmese                                   ဗမာ
- my-MM            Burmese Myanmar (Burma)                   ဗမာ မြန်မာ
+ my               Burmese                                   မြန်မာ
+ my-MM            Burmese Myanmar (Burma)                   မြန်မာ မြန်မာ
  mzn              Mazanderani                               مازرونی
  mzn-IR           Mazanderani Iran                          مازرونی ایران
  naq              Nama                                      Khoekhoegowab
@@ -547,6 +549,9 @@ The available locales are:
  nb-SJ            Norwegian Bokmål Svalbard & Jan Mayen     norsk bokmål Svalbard og Jan Mayen
  nd               North Ndebele                             isiNdebele
  nd-ZW            North Ndebele Zimbabwe                    isiNdebele Zimbabwe
+ nds              Low German
+ nds-DE           Low German Germany                        DE
+ nds-NL           Low German Netherlands                    NL
  ne               Nepali                                    नेपाली
  ne-IN            Nepali India                              नेपाली भारत
  ne-NP            Nepali Nepal                              नेपाली नेपाल
@@ -571,14 +576,14 @@ The available locales are:
  om               Oromo                                     Oromoo
  om-ET            Oromo Ethiopia                            Oromoo Itoophiyaa
  om-KE            Oromo Kenya                               Oromoo Keeniyaa
- or               Oriya                                     ଓଡ଼ିଆ
- or-IN            Oriya India                               ଓଡ଼ିଆ ଭାରତ
+ or               Odia                                      ଓଡ଼ିଆ
+ or-IN            Odia India                                ଓଡ଼ିଆ ଭାରତ
  os               Ossetic                                   ирон
  os-GE            Ossetic Georgia                           ирон Гуырдзыстон
  os-RU            Ossetic Russia                            ирон Уӕрӕсе
  pa               Punjabi                                   ਪੰਜਾਬੀ
  pa-Arab          Punjabi Arabic                            پنجابی عربی
- pa-Arab-PK       Punjabi Pakistan Arabic                   پنجابی پکستان عربی
+ pa-Arab-PK       Punjabi Pakistan Arabic                   پنجابی پاکستان عربی
  pa-Guru          Punjabi Gurmukhi                          ਪੰਜਾਬੀ ਗੁਰਮੁਖੀ
  pa-Guru-IN       Punjabi India Gurmukhi                    ਪੰਜਾਬੀ ਭਾਰਤ ਗੁਰਮੁਖੀ
  pl               Polish                                    polski
@@ -590,8 +595,11 @@ The available locales are:
  pt               Portuguese                                português
  pt-AO            Portuguese Angola                         português Angola
  pt-BR            Portuguese Brazil                         português Brasil
+ pt-CH            Portuguese Switzerland                    português Suíça
  pt-CV            Portuguese Cape Verde                     português Cabo Verde
+ pt-GQ            Portuguese Equatorial Guinea              português Guiné Equatorial
  pt-GW            Portuguese Guinea-Bissau                  português Guiné-Bissau
+ pt-LU            Portuguese Luxembourg                     português Luxemburgo
  pt-MO            Portuguese Macau SAR China                português Macau, RAE da China
  pt-MZ            Portuguese Mozambique                     português Moçambique
  pt-PT            Portuguese Portugal                       português Portugal
@@ -702,7 +710,7 @@ The available locales are:
  to               Tongan                                    lea fakatonga
  to-TO            Tongan Tonga                              lea fakatonga Tonga
  tr               Turkish                                   Türkçe
- tr-CY            Turkish Cyprus                            Türkçe Güney Kıbrıs Rum Kesimi
+ tr-CY            Turkish Cyprus                            Türkçe Kıbrıs
  tr-TR            Turkish Turkey                            Türkçe Türkiye
  twq              Tasawaq                                   Tasawaq senni
  twq-NE           Tasawaq Niger                             Tasawaq senni Nižer
@@ -718,8 +726,8 @@ The available locales are:
  uz               Uzbek                                     o‘zbek
  uz-Arab          Uzbek Arabic                              اوزبیک عربی
  uz-Arab-AF       Uzbek Afghanistan Arabic                  اوزبیک افغانستان عربی
- uz-Cyrl          Uzbek Cyrillic                            Ўзбек Кирил
- uz-Cyrl-UZ       Uzbek Uzbekistan Cyrillic                 Ўзбек Ўзбекистон Кирил
+ uz-Cyrl          Uzbek Cyrillic                            ўзбекча Кирил
+ uz-Cyrl-UZ       Uzbek Uzbekistan Cyrillic                 ўзбекча Ўзбекистон Кирил
  uz-Latn          Uzbek Latin                               o‘zbek lotin
  uz-Latn-UZ       Uzbek Uzbekistan Latin                    o‘zbek Oʻzbekiston lotin
  vai              Vai                                       ꕙꔤ
@@ -744,6 +752,8 @@ The available locales are:
  yo               Yoruba                                    Èdè Yorùbá
  yo-BJ            Yoruba Benin                              Èdè Yorùbá Orílɛ́ède Bɛ̀nɛ̀
  yo-NG            Yoruba Nigeria                            Èdè Yorùbá Orílẹ́ède Nàìjíríà
+ yue              Cantonese                                 粵語
+ yue-HK           Cantonese Hong Kong SAR China             粵語 中華人民共和國香港特別行政區
  zgh              Standard Moroccan Tamazight               ⵜⴰⵎⴰⵣⵉⵖⵜ
  zgh-MA           Standard Moroccan Tamazight Morocco       ⵜⴰⵎⴰⵣⵉⵖⵜ ⵍⵎⵖⵔⵉⴱ
  zh               Chinese                                   中文
@@ -753,21 +763,37 @@ The available locales are:
  zh-Hans-MO       Chinese Macau SAR China Simplified        中文 中国澳门特别行政区 简体
  zh-Hans-SG       Chinese Singapore Simplified              中文 新加坡 简体
  zh-Hant          Chinese Traditional                       中文 繁體
- zh-Hant-HK       Chinese Hong Kong SAR China Traditional   中文 中華人民共和國香港特別行政區 繁體字
- zh-Hant-MO       Chinese Macau SAR China Traditional       中文 中華人民共和國澳門特別行政區 繁體字
+ zh-Hant-HK       Chinese Hong Kong SAR China Traditional   中文 中國香港特別行政區 繁體字
+ zh-Hant-MO       Chinese Macau SAR China Traditional       中文 中國澳門特別行政區 繁體字
  zh-Hant-TW       Chinese Taiwan Traditional                中文 台灣 繁體
  zu               Zulu                                      isiZulu
  zu-ZA            Zulu South Africa                         isiZulu i-South Africa
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issues>.
+
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dave Rolsky.
+This software is copyright (c) 2003 - 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
