@@ -2,11 +2,13 @@ package DateTime::Locale::FromData;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
 use DateTime::Locale::Util qw( parse_locale_code );
-use Params::Validate qw( validate_pos );
+use Params::ValidationCompiler 0.13 qw( validation_for );
+use Specio::Declare;
 
-our $VERSION = '0.96';
+our $VERSION = '1.15';
 
 my @FormatLengths;
 
@@ -133,18 +135,23 @@ sub _make_datetime_format {
     return $dt_format;
 }
 
+my $length = enum( values => [qw( full long medium short )] );
+my $validator = validation_for(
+    name             => '_check_length_parameter',
+    name_is_optional => 1,
+    params           => [ { type => $length } ],
+);
+
 sub set_default_date_format_length {
     my $self = shift;
-    my ($l)
-        = validate_pos( @_, { regex => qr/^(?:full|long|medium|short)$/i } );
+    my ($l) = $validator->(@_);
 
     $self->{default_date_format_length} = lc $l;
 }
 
 sub set_default_time_format_length {
     my $self = shift;
-    my ($l)
-        = validate_pos( @_, { regex => qr/^(?:full|long|medium|short)/i } );
+    my ($l) = $validator->(@_);
 
     $self->{default_time_format_length} = lc $l;
 }
@@ -196,26 +203,26 @@ sub prefers_24_hour_time {
 
 sub language_code {
     my $self = shift;
-    return ( $self->{parsed_code} ||= [ parse_locale_code( $self->code ) ] )
-        ->[0];
+    return ( $self->{parsed_code} ||= { parse_locale_code( $self->code ) } )
+        ->{language};
 }
 
 sub script_code {
     my $self = shift;
-    return ( $self->{parsed_code} ||= [ parse_locale_code( $self->code ) ] )
-        ->[1];
+    return ( $self->{parsed_code} ||= { parse_locale_code( $self->code ) } )
+        ->{script};
 }
 
 sub territory_code {
     my $self = shift;
-    return ( $self->{parsed_code} ||= [ parse_locale_code( $self->code ) ] )
-        ->[2];
+    return ( $self->{parsed_code} ||= { parse_locale_code( $self->code ) } )
+        ->{territory};
 }
 
 sub variant_code {
     my $self = shift;
-    return ( $self->{parsed_code} ||= [ parse_locale_code( $self->code ) ] )
-        ->[3];
+    return ( $self->{parsed_code} ||= { parse_locale_code( $self->code ) } )
+        ->{variant};
 }
 
 sub id {
@@ -267,13 +274,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Locale::FromData - Class for locale objects instantiated from pre-defined data
 
 =head1 VERSION
 
-version 0.96
+version 1.15
 
 =head1 SYNOPSIS
 
@@ -284,8 +293,6 @@ version 0.96
 This class is used to represent locales instantiated from the data in the
 DateTime::Locale::Data module.
 
-=encoding UTF-8
-
 =head1 METHODS
 
 This class provides the following methods:
@@ -486,15 +493,31 @@ The CLDR version from which this locale was generated.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issues>.
+
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dave Rolsky.
+This software is copyright (c) 2003 - 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
