@@ -11,12 +11,13 @@ use autodie;
 
 use Data::Dumper::Concise qw( Dumper );
 use JSON::MaybeXS qw( decode_json );
-use List::AllUtils qw( max );
+use List::AllUtils qw( max uniq );
 use ModuleGenerator::Locale;
-use Locale::Language
+use Locale::Codes::Language
     qw( language_code2code LOCALE_LANG_ALPHA_2 LOCALE_LANG_ALPHA_3 );
 use Parse::PMFile;
 use Path::Class qw( file );
+use Path::Class::Rule;
 use Scalar::Util qw( reftype );
 use Text::Template;
 
@@ -32,6 +33,18 @@ with 'MooseX::Getopt::Dashes';
 
 our $VERSION = '0.10';
 
+has _only_locales => (
+    traits   => ['Array'],
+    is       => 'ro',
+    isa      => ArrayRef [Str],
+    init_arg => 'locales',
+    default  => sub { [] },
+    handles  => {
+        _has_only_locales => 'count',
+    },
+    documentation => 'If specified, only these locales will be built.',
+);
+
 has _autogen_warning => (
     is      => 'ro',
     isa     => Str,
@@ -39,11 +52,11 @@ has _autogen_warning => (
     builder => '_build_autogen_warning',
 );
 
-has _script => (
+has _generator_script => (
     is      => 'ro',
     isa     => File,
     lazy    => 1,
-    builder => '_build_script',
+    builder => '_build_generator_script',
 );
 
 has _source_data_root => (
@@ -68,14 +81,25 @@ has _locales => (
 );
 
 sub run ($self) {
+    $self->_clean_old_data;
     $self->_locales;
-    $self->_write_data_pm;
+    $self->_write_data_files;
     $self->_write_catalog_pm;
     $self->_write_pod_files;
 
     return 0;
 }
 
+sub _clean_old_data ($self) {
+    my $pir  = Path::Class::Rule->new;
+    my $iter = $pir->file->name(qr/\.pod$/)->iter('lib');
+    while ( my $path = $iter->() ) {
+        ## no critic (InputOutput::RequireCheckedSyscalls)
+        say 'Removing ', $path->basename;
+        $path->remove;
+    }
+}
+
 sub _build_locales ($self) {
     my @locales;
     for my $code ( $self->_locale_codes->@* ) {
@@ -85,7 +109,7 @@ sub _build_locales ($self) {
         );
 
         ## no critic (InputOutput::RequireCheckedSyscalls)
-        say $locale->code;
+        say $locale->code . q{ - } . $locale->en_name;
         say $_ for $locale->source_files;
         print "\n";
         ## use critic
@@ -96,7 +120,32 @@ sub _build_locales ($self) {
     return \@locales;
 }
 
+sub _write_data_files ($self) {
+    my %raw_locales = $self->_write_data_pm;
+
+    for my $code ( sort keys %raw_locales ) {
+        my $dumped = $self->_dump_with_unicode( $raw_locales{$code} );
+        my $file = file( 'share', $code . '.pl' );
+        ## no critic (InputOutput::RequireCheckedSyscalls)
+        say "Generating $file";
+        $file->spew($dumped);
+    }
+
+    return;
+}
+
 sub _write_data_pm ($self) {
+    my %codes;
+    my %names;
+    my %native_names;
+    my %raw_locales;
+    for my $locale ( $self->_locales->@* ) {
+        $codes{ $locale->code }               = 1;
+        $names{ $locale->en_name }            = $locale->code;
+        $native_names{ $locale->native_name } = $locale->code;
+        $raw_locales{ $locale->code }         = $locale->data_hash;
+    }
+
     my $data_pm_file = file(qw( lib DateTime Locale Data.pm ));
     ## no critic (InputOutput::RequireCheckedSyscalls)
     say "Generating $data_pm_file";
@@ -105,17 +154,6 @@ sub _write_data_pm ($self) {
 
     $self->_insert_autogen_warning( \$data_pm );
 
-    my %codes;
-    my %names;
-    my %native_names;
-    my %raw_locales;
-    for my $locale ( $self->_locales->@* ) {
-        $codes{ $locale->code }               = 1;
-        $names{ $locale->en_name }            = 1;
-        $native_names{ $locale->native_name } = 1;
-        $raw_locales{ $locale->code }         = $locale->data_hash;
-    }
-
     $self->_insert_var_in_code(
         'CLDRVersion',
         $self->_locales->[0]->version, 1, \$data_pm
@@ -137,40 +175,20 @@ sub _write_data_pm ($self) {
 
     $self->_insert_var_in_code( 'LocaleData', \%preload, 0, \$data_pm );
 
-    my $pos = 0;
-    my %index;
-    my $data_section = q{};
-    for my $code ( sort keys %raw_locales ) {
-        my $marker = "__[ $code ]__\n";
-        $data_section .= $marker;
-        $pos += length $marker;
-
-        my $start_pos = $pos;
-
-        my $dumped = Dumper( $raw_locales{$code} );
-        $data_section .= $dumped;
-        $pos += length $dumped;
-
-        $index{$code} = [ $start_pos => $pos - $start_pos ];
-    }
-
-    $self->_insert_var_in_code( 'DataSectionIndex', \%index, 0, \$data_pm );
-
-    $data_pm =~ s/(__DATA__\n).*(__END__\n)/$1$data_section\n$2/s
-        or die 'data section subst failed';
-
     $data_pm_file->spew( iomode => '>:encoding(UTF-8)', $data_pm );
 
-    return;
+    return %raw_locales;
 }
 
 sub _iso_639_aliases ($self) {
     my %aliases;
     for my $locale ( $self->_locales->@* ) {
+        next if length $locale->language_code > 2;
+
         my $three = language_code2code(
             $locale->language_code,
             LOCALE_LANG_ALPHA_2, LOCALE_LANG_ALPHA_3
-        ) or next;
+        );
 
         my $full_three_code = join '-',
             grep {defined} (
@@ -224,6 +242,80 @@ sub _write_catalog_pm ($self) {
     $catalog_pm_file->spew( iomode => '>:encoding(UTF-8)', $catalog_pm );
 }
 
+sub _insert_var_in_code ( $self, $name, $value, $public, $code ) {
+    my $sigil
+        = !ref $value              ? '$'
+        : reftype $value eq 'HASH' ? '%'
+        :                            '@';
+
+    my $safe;
+    if ( ref $value ) {
+        $safe = $self->_dump_with_unicode($value);
+        $safe =~ s/^[\{\[]/(/;
+        $safe =~ s/[\}\]]\n$/)/;
+    }
+    else {
+        $safe = $value = is_Num($value) ? $value : B::perlstring($value);
+    }
+
+    my $declarator = $public ? 'our' : 'my';
+    ${$code} =~ s/
+        (\#<<<\n
+         \#\#\#\Q :start $name:\E\n)
+        .*
+        (\#\#\#\Q :end $name:\E\n
+         \#>>>\n)
+    /$1$declarator $sigil$name = $safe;\n$2/xs
+        or die "inserting $name failed";
+
+    return;
+}
+
+# Data::Dumper dumps all Unicode characters using Perl's \x{feedad0g}
+# syntax. If the character is in the 0x80-0xFF range, then Perl will not treat
+# this as a UTF-8 char when it sees it (either at compile or eval time). We
+# force it to use UTF-8 by replacing \x{feedad0g} with \N{U+feedad0g}, which
+# is always interpreted as UTF-8.
+sub _dump_with_unicode ( $self, $val ) {
+    my $dumped = Dumper($val);
+    $dumped =~ s/\\x\{([^}]+)\}/$self->_unicode_char_for($1)/eg;
+    return $dumped;
+}
+
+sub _unicode_char_for ( $, $hex ) {
+    ## no critic (BuiltinFunctions::ProhibitStringyEval)
+    my $num = eval '0x' . $hex;
+    die $@ if $@;
+    return '\N{U+' . sprintf( '%04x', $num ) . '}';
+}
+
+sub _insert_autogen_warning ( $self, $code ) {
+    ${$code} =~ s/(?:^###+$).+(?:^###+$)\n+//ms;
+    ${$code} =~ s/^/$self->_autogen_warning/e;
+    return;
+}
+
+sub _build_autogen_warning ($self) {
+    my $script = $self->_generator_script->basename;
+
+    return <<"EOF";
+###########################################################################
+#
+# This file is partially auto-generated by the DateTime::Locale generator
+# tools (v$VERSION). This code generator comes with the DateTime::Locale
+# distribution in the tools/ directory, and is called $script.
+#
+# This file was generated from the CLDR JSON locale data. See the LICENSE.cldr
+# file included in this distribution for license details.
+#
+# Do not edit this file directly unless you are sure the part you are editing
+# is not created by the generator.
+#
+###########################################################################
+
+EOF
+}
+
 sub _write_pod_files ($self) {
     my $template = Text::Template->new(
         TYPE   => 'FILE',
@@ -276,10 +368,13 @@ sub _write_pod_files ($self) {
         my $locale = DateTime::Locale->load($code)
             or die "Cannot load $code";
 
+        my $name   = $locale->name;
         my $filled = $template->fill_in(
             HASH => {
-                name        => 'DateTime::Locale::' . $underscore,
-                description => "Locale data examples for the $code locale.",
+                autogen_warning => $self->_autogen_warning,
+                name            => 'DateTime::Locale::' . $underscore,
+                description =>
+                    "Locale data examples for the $name ($code) locale",
                 example_dts => \@example_dts,
                 locale      => \$locale,
             },
@@ -291,71 +386,20 @@ sub _write_pod_files ($self) {
     return;
 }
 
-sub _insert_var_in_code($self, $name, $value, $public, $code) {
-    my $sigil
-        = !ref $value              ? '$'
-        : reftype $value eq 'HASH' ? '%'
-        :                            '@';
-
-    my $safe;
-    if ( ref $value ) {
-        $safe = Dumper($value);
-        $safe =~ s/^[\{\[]/(/;
-        $safe =~ s/[\}\]]\n$/)/;
-    }
-    else {
-        $safe = $value = is_Num($value) ? $value : B::perlstring($value);
-    }
-
-    my $declarator = $public ? 'our' : 'my';
-    ${$code} =~ s/
-        (\#<<<\n
-         \#\#\#\Q :start $name:\E\n)
-        .*
-        (\#\#\#\Q :end $name:\E\n
-         \#>>>\n)
-    /$1$declarator $sigil$name = $safe;\n$2/xs
-        or die "inserting $name failed";
-
-    return;
-}
-
-sub _insert_autogen_warning ($self, $code) {
-    ${$code} =~ s/(?:^###+$).+(?:^###+$)\n+//ms;
-    ${$code} =~ s/^/$self->_autogen_warning/e;
-    return;
-}
-
-sub _build_autogen_warning ($self) {
-    my $script = $self->_script->basename;
-
-    return <<"EOF";
-###########################################################################
-#
-# This file is partially auto-generated by the DateTime::Locale generator
-# tools (v$VERSION). This code generator comes with the DateTime::Locale
-# distribution in the tools/ directory, and is called $script.
-#
-# This file was generated from the CLDR JSON locale data. See the LICENSE.cldr
-# file included in this distribution for license details.
-#
-# Do not edit this file directly unless you are sure the part you are editing
-# is not created by the generator.
-#
-###########################################################################
-
-EOF
-}
-
-sub _build_script {
+sub _build_generator_script {
     return file($0);
 }
 
 sub _build_source_data_root ($self) {
-    return $self->_script->parent->parent->subdir('source-data');
+    return $self->_generator_script->parent->parent->subdir('source-data');
 }
 
 sub _build_locale_codes ($self) {
+
+    # We need to have en-US available so we can build a DateTime.pm object.
+    return [ uniq( 'en-US', @{ $self->_only_locales } ) ]
+        if $self->_has_only_locales;
+
     my $avail
         = decode_json(
         $self->_source_data_root->file(qw( cldr-core availableLocales.json ))
